asr.projected\_bandstructure
============================

.. automodule:: asr.projected_bandstructure

   
   
   .. rubric:: Functions

   
   .. autofunction:: get_bs_sampling
   .. autofunction:: get_orbital_ldos
   .. autofunction:: get_pie_markers
   .. autofunction:: get_pie_slice
   .. autofunction:: get_yl_ordering
   .. autofunction:: projected_bs_pbe
   .. autofunction:: webpanel
   
   

   
   
   

   
   
   